@@ -12,4 +12,11 @@ def _getClassModelsMetadata(seed):
             #,KNeighborsClassifier(n_jobs=-1)
             ,GaussianNB()
             ,RandomForestClassifier(random_state=seed,n_jobs=-1)
-            ,GradientBoostingClassifier(random_state=seed)]
\ No newline at end of file
+            ,GradientBoostingClassifier(random_state=seed)]
+
+def _getScaleModels():
+    ## list of models that would
+    ## do well on scaled data as seed
+    return ['LogisticRegression'
+            ,'GaussianNB'
+           ]
\ No newline at end of file
