@@ -3,4 +3,4 @@ import os
 
 def loadiris():
     print(os.getcwd())
-    return pd.read_csv('iris.csv')
\ No newline at end of file
+    return pd.read_csv('./tests/iris.csv')
\ No newline at end of file
